'use strict';

// const AWS = require('aws-sdk');
// const kinesis = new AWS.Kinesis({region: 'us-west-2'});

const agg = require('aws-kinesis-agg');
const deaggregateAsync = require('../../../kpl-deagg-async').deaggregateAsync;

const Strings = require('core-functions/strings');
const stringify = Strings.stringify;

// const tries = require('core-functions/tries');
// const Success = tries.Success;
// const Failure = tries.Failure;

const Promises = require('core-functions/promises');

module.exports.handler = function handler(event, awsContext, awsCallback) {
  console.log(`event = ${stringify(event)}`);
  console.log(`event (JSON) = ${JSON.stringify(event)}`);

  const recordOutcomePromises = event.Records.map(record => {
    // agg.deaggregateSync(kinesisRecord, computeCheckSums, afterRecordsCallback)
    return deaggregateAsync(record.kinesis, false);
  });

  Promises.every(recordOutcomePromises).then(
    recordOutcomes => {
      const recordSuccesses = recordOutcomes.filter(o => o.isSuccess());
      console.log(`deaggregateAsync record successes = ${recordSuccesses.length}`);
      const recordFailures = recordOutcomes.filter(o => o.isFailure());
      console.log(`deaggregateAsync record failures = ${recordFailures.length}`);

      recordOutcomes.forEach((o, i) => {
        o.map(
          userRecordOutcomes => {
            console.log(`Success userRecord[${i}] = ${stringify(userRecordOutcomes)}`);
            console.log(`Success userRecord[${i}] (JSON) = ${JSON.stringify(userRecordOutcomes)}`);
          },
          err => {
            console.log(`Failure error[${i}]`, err);
          }
        );
      });
      awsCallback(null, recordOutcomes);
    },
    err => {
      console.log(`Unexpected error`, err);
      awsCallback(err, null);
    }
  );
};
