'use strict';

// const AWS = require('aws-sdk');
// const kinesis = new AWS.Kinesis({region: 'us-west-2'});

const agg = require('aws-kinesis-agg');

const Strings = require('core-functions/strings');
const stringify = Strings.stringify;

// const tries = require('core-functions/tries');
// const Success = tries.Success;
// const Failure = tries.Failure;

const Promises = require('core-functions/promises');

// agg.deaggregateSync(kinesisRecord, computeCheckSums, afterRecordsCallback)
const deaggregateSync = Promises.wrap(agg.deaggregateSync);

module.exports.handler = function handler(event, awsContext, awsCallback) {
  console.log(`event = ${stringify(event)}`);
  console.log(`event (JSON) = ${JSON.stringify(event)}`);

  // agg.reset();
  const userRecordPromises = event.Records.map(record => {
    // agg.deaggregateSync(kinesisRecord, computeCheckSums, afterRecordsCallback)
    return deaggregateSync(record.kinesis, false);
  });

  Promises.every(userRecordPromises).then(
    outcomes => {
      const successes = outcomes.filter(o => o.isSuccess());
      console.log(`deaggregateSync successes = ${successes.length}`);
      const failures = outcomes.filter(o => o.isFailure());
      console.log(`deaggregateSync failures = ${failures.length}`);

      outcomes.forEach((o, i) => {
        o.map(
          userRecord => {
            console.log(`Success userRecord[${i}] = ${stringify(userRecord)}`);
            console.log(`Success userRecord[${i}] (JSON) = ${JSON.stringify(userRecord)}`);
          },
          err => {
            console.log(`Failure error[${i}]`, err);
          }
        );
      });
      awsCallback(null, outcomes);
    },
    err => {
      console.log(`Unexpected error`, err);
      awsCallback(err, null);
    }
  );
};
